About OpenNyAI Mission
===================================

What is OpenNyAI mission?
-------------------------
`OpenNyai <https://opennyai.org/>`_ is a mission aimed at developing open source software and datasets to catalyze the creation of AI-powered solutions to improve access to justice in India.

Innovation, accelerated by collaboration
-------------------------
OpenNyai is an open mission enabling everyone to contribute. Our community is engaged in building datasets, models, educational materials, holding community spaces and evangelising better design and ethics for AI for Justice solutions. If you are intrigued by AI for Justice solutions and want to explore ways in which you can contribute, then
please get in touch! We would love to speak to you and
figure out pathways that works best for you.

Founding Collaborators
--------------------
`Agami <https://agami.in/>`_, `EkStep <https://ekstep.org/>`_, `Thoughtworks <https://www.thoughtworks.com/en-in>`_, `National Law School Banglore <https://www.nls.ac.in/>`_, `Rohini Nilekani Philanthropies <https://rohininilekaniphilanthropies.org/>`_

Contact Us
----------
`Slack <https://join.slack.com/t/opennyai/shared_invite/zt-100y32eon-AFA20dBx04qUOjGcQ0K9kQ>`_

Email: support@agami.in

`LinkedIn <https://github.com/OpenNyAI>`_
